aboutsummaryrefslogtreecommitdiffstats
path: root/examples/network/threadedfortuneserver.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/network/threadedfortuneserver.py')
-rw-r--r--examples/network/threadedfortuneserver.py8
1 files changed, 4 insertions, 4 deletions
diff --git a/examples/network/threadedfortuneserver.py b/examples/network/threadedfortuneserver.py
index c16c77a27..839a2a57e 100644
--- a/examples/network/threadedfortuneserver.py
+++ b/examples/network/threadedfortuneserver.py
@@ -40,15 +40,15 @@
##
#############################################################################
"""PySide2 port of the network/threadedfortuneserver example from Qt v5.x, originating from PyQt"""
import random
-from PySide2.QtCore import (Signal, QByteArray, QDataStream, QIODevice,
+from PySide6.QtCore import (Signal, QByteArray, QDataStream, QIODevice,
QThread, Qt)
-from PySide2.QtWidgets import (QApplication, QDialog, QHBoxLayout, QLabel,
+from PySide6.QtWidgets import (QApplication, QDialog, QHBoxLayout, QLabel,
QMessageBox, QPushButton, QVBoxLayout)
-from PySide2.QtNetwork import (QHostAddress, QNetworkInterface, QTcpServer,
+from PySide6.QtNetwork import (QHostAddress, QNetworkInterface, QTcpServer,
QTcpSocket)
@@ -40,15 +40,15 @@
##
#############################################################################
-"""PySide2 port of the network/threadedfortuneserver example from Qt v5.x, originating from PyQt"""
+"""PySide6 port of the network/threadedfortuneserver example from Qt v5.x, originating from PyQt"""
import random